@@ -5,11 +5,12 @@ use strict;
 use warnings;
 use Carp;
 use Scalar::Util qw(blessed);
-use Log::Log4perl qw(get_logger);
+use Log::Any qw($log);
 use Farly::ASA::PortFormatter;
 use Farly::ASA::ProtocolFormatter;
 use Farly::ASA::ICMPFormatter;
-our $VERSION = '0.24';
+
+our $VERSION = '0.25';
 our $AUTOLOAD;
 
 #each token type maps to a class
@@ -69,9 +70,8 @@ sub new {
         ICMP_FMT     => Farly::ASA::ICMPFormatter->new()
     };
     bless $self, $class;
-
-    my $logger = get_logger(__PACKAGE__);
-    $logger->info("$self NEW");
+    
+    $log->info("$self new");
 
     return $self;
 }
@@ -137,15 +137,14 @@ sub visit {
 sub named_ip {
     my ( $self, $node ) = @_;
 
-    my $logger = get_logger(__PACKAGE__);
-
     my $name = $node->{name}->{NAME_ID}->{__VALUE__}
       or confess "$self error: name not found for ", ref($node);
 
     my $ip = $node->{IPADDRESS}->{__VALUE__}
       or confess "$self error: IP address not found for ", ref($node);
 
-    $logger->debug("name: $name ip: $ip");
+    $log->debug("name = $name : ip = $ip");
+
     $self->{NAMES}->{$name} = $ip;
 }
 
@@ -190,8 +189,7 @@ sub ICMP_TYPE {
 
     my $icmp_type = $node->{'__VALUE__'};
 
-    $node->{'__VALUE__'} =
-      defined( $self->icmp_formatter()->as_integer($icmp_type) )
+    $node->{'__VALUE__'} = defined( $self->icmp_formatter()->as_integer($icmp_type) )
       ? Farly::IPv4::ICMPType->new( $self->icmp_formatter()->as_integer($icmp_type) )
       : Farly::IPv4::ICMPType->new($icmp_type);
 }
@@ -201,8 +199,7 @@ sub PROTOCOL {
 
     my $protocol = $node->{'__VALUE__'};
 
-    $node->{'__VALUE__'} =
-      defined( $self->protocol_formatter()->as_integer($protocol) )
+    $node->{'__VALUE__'} = defined( $self->protocol_formatter()->as_integer($protocol) )
       ? Farly::Transport::Protocol->new( $self->protocol_formatter()->as_integer($protocol) )
       : Farly::Transport::Protocol->new($protocol);
 }
@@ -212,8 +209,7 @@ sub PORT_ID {
 
     my $port = $node->{'__VALUE__'};
 
-    $node->{'__VALUE__'} =
-      defined( $self->port_formatter()->as_integer($port) )
+    $node->{'__VALUE__'} = defined( $self->port_formatter()->as_integer($port) )
       ? Farly::Transport::Port->new( $self->port_formatter()->as_integer($port) )
       : Farly::Transport::Port->new($port);
 }
@@ -241,8 +237,7 @@ sub PORT_GT {
 
     my $port = $node->{'__VALUE__'};
 
-    $node->{'__VALUE__'} =
-      defined( $self->port_formatter()->as_integer($port) )
+    $node->{'__VALUE__'} = defined( $self->port_formatter()->as_integer($port) )
       ? Farly::Transport::PortGT->new( $self->port_formatter()->as_integer($port) )
       : Farly::Transport::PortGT->new($port);
 }
@@ -252,8 +247,7 @@ sub PORT_LT {
 
     my $port = $node->{'__VALUE__'};
 
-    $node->{'__VALUE__'} =
-      defined( $self->port_formatter()->as_integer($port) )
+    $node->{'__VALUE__'} = defined( $self->port_formatter()->as_integer($port) )
       ? Farly::Transport::PortLT->new( $self->port_formatter()->as_integer($port) )
       : Farly::Transport::PortLT->new($port);
 }
@@ -294,12 +288,10 @@ sub AUTOLOAD {
     my $value = $node->{'__VALUE__'};
 
     if ( $class eq 'Farly::Object::Ref' ) {
-
         #need to set 'ENTRY' and 'ID' properties
         $object = $self->_new_ObjectRef( $token_class, $value );
     }
     else {
-
         #create the object right away
         $object = $class->new($value);
     }
